@@ -99,6 +99,10 @@ use InSilicoSpectro::Spectra::MSMSSpectra;
 %handlers=(
 	   txt=>{write=>\&writeTxt,
 		},
+	   mgf=>{
+		 write=>\&writeMGF,
+		 description=>"Mascot generic format (mgf)"
+		},
 	      );
 
 sub new{
@@ -277,6 +281,11 @@ sub writeTxt{
   print "\n";
 }
 
+sub writeMGF{
+  my ($this)=@_;
+  return;
+}
+
 sub writePLE{
   my ($this, $shift)=@_;
   my $transformChargeMask=1;
